@@ -8,7 +8,7 @@ class gitricsEpic(GitlabEpic):
     gitricsEpic is a Gitlab Epic with opinionated enrichment for the gitrics ecosystem.
     """
 
-    def __init__(self, id: str = None, iid: str = None, epic: dict = None, group_id: str = None, group_graph: nx.DiGraph = None, token: str = configuration.GITLAB_TOKEN, version: str = configuration.GITLAB_API_VERSION):
+    def __init__(self, id: str = None, iid: str = None, epic: dict = None, group_id: str = None, group_graph: nx.DiGraph = None, notes: list = None, ownership: list = None, token: str = configuration.GITLAB_TOKEN, version: str = configuration.GITLAB_API_VERSION):
         """
         Args:
             id (string): GitLab Epic id
@@ -16,6 +16,8 @@ class gitricsEpic(GitlabEpic):
             epic (dictionary): GitLab Epic
             group_graph (DiGraph): networkx directional graph
             group_id (string): Gitlab Group id
+            notes (list): dictionaries of GitLab notes (comments)
+            ownership (list): classes of GitlabUser
             token (string): GitLab personal access, ci, or deploy token
             version (string): GitLab API version as base url
         """
@@ -24,7 +26,7 @@ class gitricsEpic(GitlabEpic):
         self.issues = None
         self.count_at_risk = 0
         self.count_on_track = 0
-        self.ownership = None
+        self.ownership = ownership
         self.percent_complete = 0
         self.score_at_risk = 0
         self.score_on_track = 0
@@ -34,6 +36,7 @@ class gitricsEpic(GitlabEpic):
             epic=epic,
             group_id=group_id,
             iid=iid,
+            notes=notes,
             token=token,
             version=version
         )
